/*
 * Copyright (c) 2014, Juniper Networks, Inc.
 * All rights reserved.
 *
 * see COPYING file
 */

#ifndef __EFI_JNPR_H__
#define __EFI_JNPR_H__

#include "JuniperUEFIRevokedKeys.h"

/*
 * This is the non-volagtile, runtine/bootserver EFI variable, where
 * we keep various breadcrumbs -- or flags.
 */
extern uint64_t jsetup;
extern EFI_GUID JSETUP_GUID;

/* known flags */
#define JSETUP_DEV_KEYS_REVOKED (1 << 0)
#define JSETUP_FACTORY_SB_RESTORED (1 << 1)

/* variable metadata */
#ifdef BUILD_EFI
#define JSETUP_VAR_NAME L"JSetup"
#define REVOKE_VAR_NAME L"dbx"
#else
#define JSETUP_VAR_NAME "JSetup"
#define REVOKE_VAR_NAME "dbx"
#endif
#define JSETUP_VAR_OWNER &JSETUP_GUID

#define REVOKE_VAR_OWNER &SIG_DB

/*
 * Juniper currently supports 2 types of
 * EFI revocations:
 * - X509   -- BIOS revocations
 * - SHA256 -- BOOTLOADER revocations
 *
 * Must be kept in sync with efi_revocation_type_to_str()
 */
typedef enum efi_revocation_type {
	EFI_REVOCATION_X509,
	EFI_REVOCATION_SHA256,
} efi_revocation_type_e;

typedef struct efi_revocation {
	efi_revocation_type_e ert;		/* Type of the revication */
	SLIST_ENTRY(efi_revocation) next;	/* next entry */
	void *value;		/* Opaque value, per type of the revocation */
	size_t value_len;			/* length of the value */
} efi_revocation_t;

SLIST_HEAD(revocation_set, efi_revocation);

const char *efi_revocation_type_to_str(efi_revocation_type_e);
int efi_revoke_rest(struct revocation_set *, efi_key_type_e);
int efi_revoke_rest_bringup(struct revocation_set *);
int efi_revoke_rest_dev(struct revocation_set *);
int juniper_assert_revocation(void);
int juniper_revoke_dev_keys(void);
int juniper_revoke_bringup_keys(void);
int set_revocation_breadcrumb(void);
struct revocation_set *parse_revocations(uint8_t *, uint32_t *);
void efi_revocation_set_free(struct revocation_set *);

#endif /* __EFI_JNPR_H__ */
